@@ -51,7 +51,7 @@ def _update_airflow_kube_config(airflow_kube_config, engine_config):
     # We still are mapping databand KubeConfig -> airflow KubeConfig as some functions are using values from it.
     ec = engine_config
 
-    secrets = ec.get_secrets()
+    secrets = ec.get_secrets(include_system_secrets=True)
     if secrets:
         kube_secrets = {}
         env_from_secret_ref = []
@@ -205,6 +205,7 @@ class DbndKubernetesScheduler(AirflowKubernetesScheduler):
                 "try_number": str(try_number),
             },
             try_number=try_number,
+            include_system_secrets=True,
         )
 
         pod_ctrl = self.kube_dbnd.get_pod_ctrl_for_pod(pod)
@@ -317,6 +318,10 @@ class DbndKubernetesJobWatcher(KubernetesJobWatcher):
 
     def run(self):
         """Performs watching"""
+
+        # Must reset filesystem cache to avoid using out-of-cluster credentials within Kubernetes
+        self.reset_fs_cache()
+
         kube_client = self.kube_dbnd.kube_client
         try:
             while True:
@@ -443,3 +448,8 @@ class DbndKubernetesJobWatcher(KubernetesJobWatcher):
                 labels,
                 resource_version,
             )
+
+    def reset_fs_cache(self):
+        from targets.fs import reset_fs_cache
+
+        reset_fs_cache()
